Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(8376)

Unified Diff: fetch_configs/pdfium.py

Issue 1494793002: Rename recipes/ to fetch_configs/ (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/tools/depot_tools
Patch Set: Renamed recipes to configs Created 5 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « fetch_configs/naclports.py ('k') | fetch_configs/skia.py » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: fetch_configs/pdfium.py
diff --git a/recipes/pdfium.py b/fetch_configs/pdfium.py
similarity index 81%
rename from recipes/pdfium.py
rename to fetch_configs/pdfium.py
index b3c237cfd7154f71ce70d9ddc3cc851289f55a54..a8400c1821ccbe4e6162644eedd51a4c8b37089e 100644
--- a/recipes/pdfium.py
+++ b/fetch_configs/pdfium.py
@@ -4,13 +4,13 @@
import sys
-import recipe_util # pylint: disable=F0401
+import config_util # pylint: disable=F0401
# This class doesn't need an __init__ method, so we disable the warning
# pylint: disable=W0232
-class PdfiumRecipe(recipe_util.Recipe):
- """Basic Recipe class for pdfium."""
+class PdfiumConfig(config_util.Config):
+ """Basic Config class for pdfium."""
@staticmethod
def fetch_spec(props):
@@ -33,7 +33,7 @@ class PdfiumRecipe(recipe_util.Recipe):
def main(argv=None):
- return PdfiumRecipe().handle_args(argv)
+ return PdfiumConfig().handle_args(argv)
if __name__ == '__main__':
« no previous file with comments | « fetch_configs/naclports.py ('k') | fetch_configs/skia.py » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698